<?php
/**
 * Flickr widget.
 *
 * @package    Silver
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Silver_Flickr_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_ops = array(
			'classname'   => 'widget_flickr widget-flickr row-3',
			'description' => esc_html__( 'Display your Flickr feed.', 'silver' ),
			'customize_selective_refresh' => true,
		);

		// Create the widget.
		parent::__construct(
			'silver-flickr',                          // $this->id_base
			esc_html__( '&raquo; Flickr', 'silver' ), // $this->name
			$widget_ops                               // $this->widget_options
		);

		$this->alt_option_name = 'widget_flickr';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Social widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$id    = isset( $instance['id'] ) ? esc_attr( $instance['id'] ) : '';
		$limit = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 9;

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

		// If the title not empty, display it.
		if ( $title ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $title, $instance, $this->id_base ) . $args['after_title'];
		}
		?>
			<div id="flickr"></div>

			<?php if ( $id ) : ?>
				<script>
					( function( $ ) {
						$( function() {
							$( '#flickr' ).flickrfeed( '<?php echo $id; ?>', {
								limit: <?php echo $limit; ?>,
								imagesize: 'medium',
								class: 'widget-thumb'
							});
						} );
					}( jQuery ) );
				</script>
			<?php endif; ?>
		<?php
		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance           = $old_instance;
		$instance['title']  = sanitize_text_field( $new_instance['title'] );
		$instance['id']     = sanitize_text_field( $new_instance['id'] );
		$instance['limit']  = (int) $new_instance['limit'];
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : esc_html__( 'Flickr', 'silver' );
		$id    = isset( $instance['id'] ) ? esc_attr( $instance['id'] ) : '';
		$limit = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 6;
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'silver' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'id' ); ?>">
				<?php esc_html_e( 'User ID', 'silver' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'id' ); ?>" name="<?php echo $this->get_field_name( 'id' ); ?>" value="<?php echo $id; ?>" />
			<small><?php printf( esc_html__( '%1$sGet the User ID here%2$s', 'silver' ), '<a href="http://idgettr.com/" target="_blank">', '</a>' ) ?></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php esc_html_e( 'Number of photos to show', 'silver' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo $limit; ?>" />
		</p>

	<?php

	}

}
